import 'dart:io';

import 'package:common_utils/common_utils.dart';
import 'package:flutter/material.dart';
import 'package:linkv_rtc_im_mini/bean/lv_im_msg.dart';
import 'package:linkv_rtc_im_mini/rtm_flutter_plugin.dart';

class MediaMsgModel {
  String title;
  int subType;// 0文本  1图片 2音频 3视频
  Map json;
  var msg;

  static MediaMsgModel init(title,subType, json,{var msg}) {
    MediaMsgModel model = MediaMsgModel();
    model.title = title;
    model.subType = subType;
    model.json = json;
    model.msg = msg;
    return model;
  }
}

class MessageReadedAckPage extends StatefulWidget {
  MessageReadedAckPage({Key key, @required this.userid})
      : super(key: key);
  final String userid;

  @override
  _MessageReadedAckPageState createState() => _MessageReadedAckPageState();
}

class _MessageReadedAckPageState extends State<MessageReadedAckPage> {

  static const String TAG = "_MessageReadedAckPageState";
  List<MediaMsgModel> _msgList = <MediaMsgModel>[];
  TextEditingController msgController = TextEditingController();
  FocusNode focusNode = FocusNode();

  @override
  void initState() {
    super.initState();
    RtmFlutterPlugin.queryUnReadMessageList(
            widget.userid, 9999999, 50, true)
        .then((listData) {
      if (!ObjectUtil.isEmptyList(listData) && listData.length > 0) {
        List<Map> listSetRead = [];
        for (LVIMMsg lvImMsg in listData) {
          _msgList.add(MediaMsgModel.init(
              lvImMsg.dbid.toString(), lvImMsg.subType, lvImMsg.toMap(),
              msg: lvImMsg));
          listSetRead.add(lvImMsg.toMap());
        }
        setState(() {});

        RtmFlutterPlugin.sendPrivateMessageReadedAck(listSetRead, widget.userid)
            .then((result) {
          print(TAG + "sendPrivateMessageReadedAck" + " code = ${result}");
        });
      }
    });

  }

  @override
  void dispose() {
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text("测试媒体文件消息"),
      ),
      body: GestureDetector(
        onTap: () {
          FocusScope.of(context).requestFocus(FocusNode());
        },
        child: Column(
          children: [
            Expanded(
              child: ListView.builder(
                itemBuilder: (ctx, index) {
                  var msg = _msgList[index].msg;
                  Widget mediaWidget = Container();
                  if ((_msgList[index].subType == 1 ||
                      _msgList[index].subType == 3) && msg != null && msg.imageFile != null && !ObjectUtil.isEmptyString(msg?.imageFile["localPath"])) {
                    mediaWidget = Image.file(File(msg.imageFile["localPath"]));
                  }
                  return Column(
                    crossAxisAlignment: CrossAxisAlignment.start,
                    children: [
                      InkWell(
                        onTap: () {
                          if (_msgList[index].subType == 1){//图片
                            downloadImage(_msgList[index].json,index);
                          } else if (_msgList[index].subType == 2) { //音频
                            downloadAudio(_msgList[index].json,index);
                          } else if (_msgList[index].subType == 3) { //视频
                            downloadVideoImage(_msgList[index].json,index);
                          }
                        },
                        child: Container(
                          padding: const EdgeInsets.only(left: 10, right: 10),
                          height: 50,
                          alignment: Alignment.centerLeft,
                          child: (_msgList[index].msg != null)
                              ? Row(
                            children: [
                              mediaWidget,
                              Text("${_msgList[index].title}")
                            ],
                          )
                              : Text(_msgList[index].title),
                        ),
                      ),
                      Container(height: 1, color: Colors.grey),
                    ],
                  );
                },
                itemCount: _msgList.length,
              ),
            ),
          ],
        ),
      ),
    );
  }

  ///下载音频文件
  void downloadAudio(json, index) {
    if (ObjectUtil.isEmptyMap(json)) {
      return;
    }
    print(TAG + "下载音频文件");
    RtmFlutterPlugin.downloadAudio(json).then((result) {
      print(TAG + "downloadAudio" + " code = ${result.eCode}");
    });
  }

  ///下载图片文件
  void downloadImage(json,index) {
    if (ObjectUtil.isEmptyMap(json)) {
      return;
    }
    print(TAG + "下载图片文件");
    RtmFlutterPlugin.downloadImage(json).then((result) {
      print(TAG + "downloadImage" + " code = ${result.eCode}");
      if(result.eCode == 0){
        _msgList[index].msg = result.msg;
        setState(() { });
      }
    });
  }

  ///下载视频首帧
  void downloadVideoImage(json,index) {
    if (ObjectUtil.isEmptyMap(json)) {
      return;
    }
    print(TAG + "下载视频首帧");
    RtmFlutterPlugin.downloadVideoImage(json).then((result) {
      print(TAG + "downloadVideoImage" + " code = ${result.eCode}");
      _msgList[index].msg = result.msg;
      setState(() { });
    });
  }

}