//
//  LVIMAudioMessage.h
//  CMIMLib
//
//  Created by 鹿容 on 2021/9/23.
//  Copyright © 2021 cmcm. All rights reserved.
//

#import "LVIMMediaMessage.h"
#import "LVIMFileContent.h"

NS_ASSUME_NONNULL_BEGIN

@interface LVIMAudioMessage : LVIMMediaMessage
//音频文件实例
@property (nonatomic,strong,readonly)LVIMFileContent *audioFile;
//音频文件二进制数据,下载后自动赋值
@property (nonatomic,strong,readonly)NSData *audioData;
//音频时长
@property (nonatomic,assign,readonly)float duration;

/**
 @brief 构建音频私信请求
 @param mLVsgID 本地消息ID, + [LVIMMessage generateLocalMsgID] 函数生成,也可自行生成
 @param fid 发送者ID(用户ID)
 @param tid 接收者ID(用户ID)
 @param type 消息类型别名(类型唯一)
 @param audioPath 音频文件本地地址,建议使用wav格式
 @param pushContent 推送内容
 @return 成功返回0, 否则返回非0
 **/
- (int)buildAudioPrivateRequest:(int64_t)mLVsgID fid:(NSString*)fid tid:(NSString*)tid type:(NSString*)type audioPath:(NSString *)audioPath content:(NSString *)content pushContent:(LVPushContent*)pushContent;

/**
 @brief 构建音频群组请求
 @param mLVsgID 本地消息ID, + [LVIMMessage generateLocalMsgID] 函数生成,也可自行生成
 @param fid 发送者ID(用户ID)
 @param tid 接收者ID(用户ID)
 @param type 消息类型别名(类型唯一)
 @param audioPath 音频文件本地地址,建议使用wav格式
 @param pushContent 推送内容
 @return 成功返回0, 否则返回非0
 **/
- (int)buildAudioGroupRequest:(int64_t)mLVsgID fid:(NSString*)fid tid:(NSString*)tid type:(NSString*)type audioPath:(NSString *)audioPath content:(NSString *)content pushContent:(LVPushContent*)pushContent;


/**
 @brief 下载资源,下载成功后,会自动给audioData赋值
 **/
- (void)downloadAudioWithProgress:(LVIM_PROGRESS_CALLBACK)progressCallback complete:(LVIM_DOWNLOAD_CALLBACK)downloadCallback;

@end

NS_ASSUME_NONNULL_END
