//
//  LVIMGroupManager.h
//  CMIMLib
//
//  Created by 鹿容 on 2021/9/10.
//  Copyright © 2021 cmcm. All rights reserved.
//

#import <Foundation/Foundation.h>
#import "LVIMEnumDefine.h"
#import "LVIMProtocols.h"
#import "LVIMUser.h"

NS_ASSUME_NONNULL_BEGIN

@interface LVIMGroupManager : NSObject


/**
 @brief 创建群
 @param gid 群ID,可为空,服务器自动生成
 @param gname 群名称
 @param nickname 用户昵称
 @param context 传入接收代理对象(可空)
 @param callback 结果回调(可空)
 @return 执行成功返回0, 否则返回非0
 **/
-(int)createGroup:(NSString*)gid
             gname:(NSString *)gname
         nickname:(NSString *)nickname
             context:(id)context
            callback:(LVIM_GROUP_STRING_CALLBACK)callback;

/**
 @brief 加入群
 @param gid 群ID
 @param nickname 用户昵称
 @param context 传入接收代理对象(可空)
 @param callback 结果回调(可空)
 @return 执行成功返回0, 否则返回非0
 **/
-(int)joinGroup:(NSString*)gid
         nickname:(NSString *)nickname
             context:(id)context
            callback:(LVIM_SEND_MESSAGE_CALLBACK)callback;

/**
 @brief 获取群的信息
 @param gid 群ID
 @param context 传入接收代理对象(可空)
 @param callback 结果回调(可空)
 @return 执行成功返回0, 否则返回非0
 **/
-(int)getGroupInfo:(NSString*)gid
             context:(id)context
            callback:(LVIM_GROUP_MODEL_CALLBACK)callback;

/**
 @brief 更新群名称
 @param gid 群ID
 @param gname 群名称
 @param context 传入接收代理对象(可空)
 @param callback 结果回调(可空)
 @return 执行成功返回0, 否则返回非0
 **/
-(int)updateGroupName:(NSString*)gid
            gname:(NSString *)gname
             context:(id)context
            callback:(LVIM_SEND_MESSAGE_CALLBACK)callback;

/**
 @brief 转让管理员
 @param gid 群ID
 @param touid 新管理员的ID
 @param context 传入接收代理对象(可空)
 @param callback 结果回调(可空)
 @return 执行成功返回0, 否则返回非0
 **/
-(int)changeGroupAdmin:(NSString*)gid
            touid:(NSString *)touid
             context:(id)context
             callback:(LVIM_SEND_MESSAGE_CALLBACK)callback;

/**
 @brief 退群
 @param gid 群ID
 @param context 传入接收代理对象(可空)
 @param callback 结果回调(可空)
 @return 执行成功返回0, 否则返回非0
 **/
-(int)leaveGroup:(NSString*)gid
             context:(id)context
            callback:(LVIM_SEND_MESSAGE_CALLBACK)callback;

/**
 @brief 解散群
 @param gid 群ID
 @param block ,值为1是是解散群
 @param context 传入接收代理对象(可空)
 @param callback 结果回调(可空)
 @return 执行成功返回0, 否则返回非0
 **/
-(int)operateGroup:(NSString*)gid
             block:(int)block
             context:(id)context
            callback:(LVIM_SEND_MESSAGE_CALLBACK)callback;

/**
 @brief 编辑群备注
 @param gid 群ID
 @param topic 群备注
 @param context 传入接收代理对象(可空)
 @param callback 结果回调(可空)
 @return 执行成功返回0, 否则返回非0
 **/
-(int)editGroupTopic:(NSString*)gid
              topic:(NSString *)topic
             context:(id)context
            callback:(LVIM_SEND_MESSAGE_CALLBACK)callback;

/**
 @brief 群个人禁言
 @param gid 群ID
 @param touid 被禁言用户
 @param isAdd true为禁言,false为取消禁言
 @param context 传入接收代理对象(可空)
 @param callback 结果回调(可空)
 @return 执行成功返回0, 否则返回非0
 **/
-(int)groupGag:(NSString*)gid
               touid:(NSString *)touid
               isAdd:(BOOL)isAdd
             context:(id)context
            callback:(LVIM_SEND_MESSAGE_CALLBACK)callback;

/**
 @brief 群全体禁言
 @param gid 群ID
 @param isAdd true为禁言,false为取消禁言
 @param context 传入接收代理对象(可空)
 @param callback 结果回调(可空)
 @return 执行成功返回0, 否则返回非0
 **/
-(int)groupAllGag:(NSString*)gid
               isAdd:(BOOL)isAdd
             context:(id)context
         callback:(LVIM_SEND_MESSAGE_CALLBACK)callback;

/**
 @brief 群踢人
 @param gid 群ID
 @param touid 被禁言用户
 @param context 传入接收代理对象(可空)
 @param callback 结果回调(可空)
 @return 执行成功返回0, 否则返回非0
 **/
-(int)groupKick:(NSString*)gid
               touid:(NSString *)touid
             context:(id)context
       callback:(LVIM_SEND_MESSAGE_CALLBACK)callback;

/**
 @brief 群消息推送通知
 @param gid 群ID
 @param open true开启,false为关闭,默认是开启
 @param context 传入接收代理对象(可空)
 @param callback 结果回调(可空)
 @return 执行成功返回0, 否则返回非0
 **/
-(int)groupNotifiable:(NSString*)gid
               open:(BOOL)open
             context:(id)context
             callback:(LVIM_SEND_MESSAGE_CALLBACK)callback;

/**
 @brief 获取用户所在群列表的本地缓存数据
 @return 群列表
 **/
-(NSArray<LVIMGroup *> *)localUserGroups;

/**
 @brief 获取群用户列表的本地缓存数据
 @param groupid 群组ID
 @return 群列表
 **/
-(NSArray<LVIMUser *> *)localGroupUsersWithGroupid:(NSString *)groupid;

/**
 @brief 获取用户所在群列表,直接返回本地的缓存,并且请求网络数据
 @param callback 网络数据回调
 @return 群列表
 **/
-(NSArray<LVIMGroup *> *)userGroupsLoadRemoteWithCallBack:(LVIM_GROUP_ARRAY_CALLBACK)callback;

/**
 @brief 获取群用户列表,直接返回本地的缓存,并且请求网络数据
 @param callback 网络数据回调
 @return 群列表
 **/
-(NSArray<LVIMUser *> *)groupUsersWithGroupid:(NSString *)groupid loadRemoteWithCallBack:(LVIM_GROUP_ARRAY_CALLBACK)callback;


/**
 @brief 设置模块群组代理(可根据需要设置)
 @param delegate 代理对象
 **/
-(void)setGroupNotifyDelegate:(id<LVIMGroupDelegate>)delegate;

@end

NS_ASSUME_NONNULL_END
