//
//  LVIMImageMessage.h
//  CMIMLib
//
//  Created by 鹿容 on 2021/9/24.
//  Copyright © 2021 cmcm. All rights reserved.
//

#import "LVIMMediaMessage.h"
#import "LVIMFileContent.h"
#import <UIKit/UIKit.h>

NS_ASSUME_NONNULL_BEGIN

@interface LVIMImageMessage : LVIMMediaMessage

//图片文件实例
@property (nonatomic,strong,readonly)LVIMFileContent *imageFile;
//图片对象,下载成功后自动赋值
@property (nonatomic,strong,readonly)UIImage *image;
//图片分辨率
@property (nonatomic,assign,readonly)CGSize imageSize;
//缩略图文件实例
@property (nonatomic,strong,readonly)LVIMFileContent *thumbnailImageFile;
//缩略图对象,下载后自动赋值
@property (nonatomic,strong,readonly)UIImage *thumbnailImage;
//缩略图分辨率
@property (nonatomic,assign,readonly)CGSize thumbnailImageSize;
//是否发送原图
@property (nonatomic,assign,readonly)BOOL isOrigin;

/**
 @brief 构建图片私信请求
 @param mLVsgID 本地消息ID, + [LVIMMessage generateLocalMsgID] 函数生成,也可自行生成
 @param fid 发送者ID(用户ID)
 @param tid 接收者ID(用户ID)
 @param type 消息类型别名(类型唯一)
 @param image 图片
 @param pushContent 推送内容
 @return 成功返回0, 否则返回非0
 **/
- (int)buildImagePrivateRequest:(int64_t)mLVsgID fid:(NSString*)fid tid:(NSString*)tid type:(NSString*)type image:(UIImage *)image originImage:(BOOL)isOrigin content:(NSString *)content imageType:(LVIM_IMAGE_FILE_TYPE)fileType pushContent:(LVPushContent*)pushContent;

/**
 @brief 构建图片群组请求
 @param mLVsgID 本地消息ID, + [LVIMMessage generateLocalMsgID] 函数生成,也可自行生成
 @param fid 发送者ID(用户ID)
 @param tid 接收者ID(用户ID)
 @param type 消息类型别名(类型唯一)
 @param image 图片
 @param pushContent 推送内容
 @return 成功返回0, 否则返回非0
 **/
- (int)buildImageGroupRequest:(int64_t)mLVsgID fid:(NSString*)fid tid:(NSString*)tid type:(NSString*)type image:(UIImage *)image originImage:(BOOL)isOrigin content:(NSString *)content imageType:(LVIM_IMAGE_FILE_TYPE)fileType pushContent:(LVPushContent*)pushContent;

/**
 @brief 下载缩略图,下载成功后,会自动给thumbnailImage赋值
 **/
- (void)downloadThumbnailImageWithProgress:(LVIM_PROGRESS_CALLBACK)progressCallback complete:(LVIM_DOWNLOAD_CALLBACK)downloadCallback;

/**
 @brief 下载大图,下载成功后,会自动给image赋值
 **/
- (void)downloadImageWithProgress:(LVIM_PROGRESS_CALLBACK)progressCallback complete:(LVIM_DOWNLOAD_CALLBACK)downloadCallback;

@end

NS_ASSUME_NONNULL_END
