//
//  LVIMMediaFileUtils.h
//  LVIMLib
//
//  Created by 鹿容 on 2022/1/17.
//  Copyright © 2022 cmcm. All rights reserved.
//

#import <Foundation/Foundation.h>
#import "LVIMEnumDefine.h"
#import "LVIMFileContent.h"
#import <UIKit/UIKit.h>

NS_ASSUME_NONNULL_BEGIN

@interface LVIMMediaFileUtils : NSObject
/**
 @brief 根据文件的key获取文件本地路径
 **/
+ (NSString *)localPathWithFileContent:(LVIMFileContent *)fileContent;

/**
 @brief 获取文件的时间
 **/
+ (float)getVideoLength:(NSURL *)URL;
/**
 @brief 读取文件数据
 **/
+ (NSData*)loadFileData:(NSString*)fname ;
/**
 @brief 音频格式转换
 **/
+ (NSData*)amrToWave:(NSData*)amr;
/**
 @brief 音频格式转换
 **/
+ (NSData*)wavToamr:(NSData*)wav;

/**
 @brief 获取缩放大小
 **/
+ (CGSize)scaleSize:(CGSize)originSize maxSize:(CGSize)maxSize;
/**
 @brief 按固定高度缩放图片
 **/
+ (UIImage *)scaleImage:(UIImage *)image withFixedHeight:(CGFloat)fixedHeight;

/**
 @brief 按照最大尺寸限制缩放图片
 **/
+ (UIImage *)scaleImage:(UIImage *)image
                maxSize:(CGSize)maxSize;

/**
 @brief 讲图片存储到本地目录
 **/
+ (BOOL)saveImageFromName:(NSString *)imagePath image:(UIImage *)image;


/**
 @brief 视频转码,默认转换成960x540的mp4文件
 **/
+ (BOOL)transVideoWithPath:(NSString *)videoPath completionHandler:(nonnull void (^)(BOOL,NSString *))handler;

/**
 @brief 获取视频的尺寸
 **/
+ (CGSize)videoSize:(NSString *)videoPath;

/**
 @brief 获取视频首帧图片
 **/
+ (UIImage *)getVideoFirstImage:(NSString *)videoPath;


@end

NS_ASSUME_NONNULL_END
